pub struct RecursiveCoreIntent {
pub k_at_depth: Vec<u32>,
pub max_extra_data_bytes: usize,
pub params: CoreNodeParams,
}Expand description
Recursive intent for a node in the aggregation tree that can construct proving keys for this node and all its children.
Fields
k_at_depth: Vec<u32>k_at_depth[i] is the log2 domain size at depth i. So it starts from the current node and goes down the
layers of the tree. Our aggregation structure is such that each layer of the tree only has a single circuit type so only one k is needed.
max_extra_data_bytes: usizeDifferent chains (e.g., Goerli) can have different maximum number of bytes in the extra data field of the block header. We configure the circuits differently based on this.
params: CoreNodeParamsImplementations
Sourceimpl RecursiveCoreIntent
impl RecursiveCoreIntent
Sourcepub fn create_and_serialize_proving_key(
self,
srs_dir: &Path,
data_dir: &Path,
cid_repo: &mut BTreeMap<CoreNodeParams, String>,
) -> Result<(AggTreeId, ProvingKey<G1Affine>, Value)>
pub fn create_and_serialize_proving_key( self, srs_dir: &Path, data_dir: &Path, cid_repo: &mut BTreeMap<CoreNodeParams, String>, ) -> Result<(AggTreeId, ProvingKey<G1Affine>, Value)>
Recursively creates and serializes proving keys and pinnings.
Computes circuit_id as the blake3 hash of the halo2 VerifyingKey written to bytes. Writes proving key to circuit_id.pk, verifying key to circuit_id.vk and pinning to circuit_id.json in the data_dir directory.
Returns the circuit_id, proving_key, pinning.
cid_repostores a mapping from the CoreNodeParams to the corresponding circuit ID. In an Axiom Core aggregation tree, the CoreNodeParams determines the node.PARAMS_DIRmust be set because the aggregation circuit creation requires reading trusted setup files (this can be removed later).